@@ -17,13 +17,18 @@ class Model(torch.nn.Sequential):
     3. 带有参数数量属性的模型，用于模型参数计数。
     4. 带有输出属性的模型，用于前向输出。
     """
-    device_parameter = torch.nn.Parameter(torch.tensor(0, dtype=torch.int64), requires_grad=False)
     
     def __init__(self, *layers):
         """
         使用层初始化模型。
         """
         super().__init__()
+    
+        device_parameter = torch.tensor([0], dtype=torch.int64)
+        # 注册设备参数
+        self.register_buffer('device_parameter', device_parameter)
+        
+        
         for idx, module in enumerate(layers):
             self.add_module(f'layer{idx}', module)
     
