@@ -202,32 +202,73 @@ class SpinConv(Model):
         straight_conv = self.stimuli(straight_conv)
         
         return direct + straight_conv
+    
+class SpinConv1d(Model):
+    """
+    旋转卷积，但是Conv1d，目的是使用池化的同时将卷积的维度转移到channel上。
+    """
+    def __init__(self, in_channels: int, out_channels: int, kernel_size: int = 3, stride: int = 1, padding=None, stimuli=nn.Hardswish, pool_kernel_size: int = 2, pool_padding: int = 0):
+        if padding is None:
+            padding = kernel_size // 2
+        hidden_channels = in_channels * pool_kernel_size
+        
+        super().__init__()
+        
+        self.conv1 = Model(
+            nn.Conv1d(in_channels=in_channels, out_channels=hidden_channels, kernel_size=kernel_size, stride=stride, padding=padding),
+            nn.MaxPool1d(kernel_size=pool_kernel_size, stride=pool_kernel_size, padding=pool_padding),
+        )
+        
+        self.conv2 = nn.Conv1d(in_channels=in_channels, out_channels=out_channels, kernel_size=kernel_size, stride=stride, padding=padding)
+        
+        self.conv_res = nn.Conv1d(in_channels=in_channels, out_channels=out_channels, kernel_size=1, stride=stride ** 2)
+        
+        self.stimuli = stimuli()
+        self.dim_unflatten = Model(
+            manipulators.Unflatten(1, (in_channels, pool_kernel_size)),
+            manipulators.Flatten(-2, -1),  # b,c, c1, w -> b,c,c1*w
+        )
+        
+    def get_output(self, x: torch.Tensor) -> torch.Tensor:
+        direct = self.conv_res(x)
+        
+        straight_conv = self.conv1(x)
+        
+        # flatten channel to the 2d dims
+        straight_conv = self.dim_unflatten(straight_conv)  # b,c,c1 -> b,c*c1
+        
+        straight_conv = self.stimuli(straight_conv)
+        
+        straight_conv = self.conv2(straight_conv)
+        
+        straight_conv = self.stimuli(straight_conv)
+        
+        return direct + straight_conv
 
 #%% main
 if __name__ == '__main__':
     print(f'start {__file__}')
-    
     sample_num = 1000
 
-    y = (torch.rand(sample_num)*5).long()
-    
-    x = torch.randn(sample_num, 3, 32, 32)
+    y = (torch.rand(sample_num) * 5).long()
+
+    x = torch.randn(sample_num, 3, 32)
     
     for i in range(sample_num):
         x_i = x[i]
-        y_i = y[i]*0.01
+        y_i = y[i] * 0.01
         x_i[x_i < y_i] = 0
         x[i] = x_i
-        
+
     #%% analyse data
-    import umap
-    d2_x = umap.UMAP(n_components=2, n_neighbors=10, min_dist=0.1).fit_transform(x.reshape(sample_num, -1))
-    
-    import matplotlib.pyplot as plt
-    plt.scatter(d2_x[:, 0], d2_x[:, 1], c=y, cmap='jet', s=1)
-    plt.colorbar()
-    plt.title('UMAP of x')
-    
+    # import umap
+    # d2_x = umap.UMAP(n_components=2, n_neighbors=10, min_dist=0.1).fit_transform(x.reshape(sample_num, -1))
+
+    # import matplotlib.pyplot as plt
+    # plt.scatter(d2_x[:, 0], d2_x[:, 1], c=y, cmap='jet', s=1)
+    # plt.colorbar()
+    # plt.title('UMAP of x')
+
     #%% train model for classification
     from .train import TrainningProcess
     from . import basic
@@ -250,9 +291,9 @@ if __name__ == '__main__':
         
         def init_model(self, record: dict = None):
             model = Model(
-                SpinConv(3, 3, kernel_size=3, stride=2, stimuli=nn.Hardswish, pool_kernel_size=2),
+                SpinConv1d(3, 3, kernel_size=3, stride=2, stimuli=nn.Hardswish, pool_kernel_size=2),
                 manipulators.Flatten(1),
-                FullConnectedLayer(3 * 8 * 8, 5, stimuli=nn.Hardswish()), 
+                FullConnectedLayer(3 * 8, 5, stimuli=nn.Hardswish()), 
             )
             
             if self.result_dir.cat('model_last.pth').exist():
@@ -264,13 +305,12 @@ if __name__ == '__main__':
             model.to(self.device)
             
             return model
-    
-    training_process = SimTrainProcess(sfs.path_of('spin_conv').ensure(), device='cuda:0', val_index=0)
-    
+
+    training_process = SimTrainProcess(sfs.path_of('spin_conv1d').ensure(), device='cuda:0', val_index=0)
+
     #%%
     training_process.train(3)
         
-        
     
     
     #%% end script
